<?php namespace App\Services;

use App\Services\Envato\EnvatoApiClient;
use App\User;
use Common\Auth\Events\UserCreated;
use Common\Auth\Roles\Role;
use Common\Auth\UserRepository as CommonUserRepository;
use Common\Settings\Settings;
use DB;
use Illuminate\Support\Arr;

class UserRepository extends CommonUserRepository {

    /**
     * @var EnvatoApiClient
     */
    private $envato;

    /**
     * @param User $user
     * @param Role $role
     * @param Settings $settings
     * @param EnvatoApiClient $envato
     */
    public function __construct(
        User $user,
        Role $role,
        Settings $settings,
        EnvatoApiClient $envato
    )
    {
        parent::__construct($user, $role, $settings);
        $this->envato = $envato;
    }

    /**
     * @param array $params
     * @return User
     */
    public function create($params)
    {
        /** @var User $user */
        $user = $this->user->forceCreate($this->formatParams($params));

        try {
            // TODO: move this into bedesk specific event listener or elsewhere
            // TODO: after user repository is refactored.
            if (isset($params['purchase_code'])) {
                $purchase = $this->envato->getPurchaseByCode($params['purchase_code']);

                $user->updatePurchases(
                    [['item' => $purchase, 'code' => $params['purchase_code']]],
                    Arr::get($purchase, 'buyer')
                );
            }

            if ( ! isset($params['roles']) || ! $this->attachRoles($user, $params['roles'])) {
                $this->assignDefaultRole($user);
            }
        } catch (\Exception $e) {
            //delete user if there were any errors creating/assigning
            //purchase codes or roles, so there are no artifacts left
            $user->delete();
            throw($e);
        }

        event(new UserCreated($user));

        return $user;
    }

    /**
     * @param array $ids
     * @return array|bool|null
     */
    public function deleteMultiple($ids)
    {
        parent::deleteMultiple($ids);

        DB::table('purchase_codes')->whereIn('user_id', $ids)->delete();

        return $ids;
    }
}